(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     31405,        741]
NotebookOptionsPosition[     29584,        709]
NotebookOutlinePosition[     30004,        726]
CellTagsIndexPosition[     29961,        723]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d70f6fec-3c94-4334-b140-c970390eeeae"],

Cell["Chapter 8, Section 8.2, Animation of Figure 8.4", "Section",
 CellChangeTimes->{{3.878892754594698*^9, 
  3.878892762482291*^9}},ExpressionUUID->"31388b24-5a67-47bb-905c-\
6837e1749e38"],

Cell["Define a graphics object to represent the Sun.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6b6891c1-2af0-4bfa-b36f-abfe3bef8e91"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sun", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.878888163925295*^9, 3.8788881639370327`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"e248a262-4101-4663-b917-10e388c56dd2"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8115817576166267`*^9, 3.811581780124024*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7bfcd704-b949-42b8-8539-4c61eb807e08"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", " ", "e_"}], "]"}], " ", ":=", " ", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878888184913851*^9, 3.878888184925157*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"a8483631-6fc6-4f4c-be66-5810b4a15242"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e13b727c-2449-4d76-92b2-53e884252fd8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\n", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", " ", "/.", " ", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", "\n", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", "\n", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.878888195406641*^9, 3.8788881954202223`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c35cf962-88a8-4778-ae92-4c686bb2d8ec"],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPath", "Input"],
 " to show points along the orbital path in the rotating frame of the \
resonant orbit defined by the two integers in ",
 StyleBox["ip", "Input"],
 ".  The points are plotted at time intervals of ",
 StyleBox["dt", "Input"],
 ". "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878989305138673*^9, 3.87898933975825*^9}, {
  3.879068897649115*^9, 3.8790689334860697`*^9}, {3.87906914089135*^9, 
  3.879069291819304*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0f46952f-34a4-4164-9f9d-bcc764542c65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotPath", "[", 
   RowBox[{"ip_", ",", " ", "a_", ",", " ", "e_", ",", " ", "dt_"}], "]"}], 
  " ", ":=", "\n", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"time", ",", "\[IndentingNewLine]", 
      RowBox[{"sun", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"box", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", 
             RowBox[{"-", "1.5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", 
             RowBox[{"-", "1.5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "1.5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", 
             RowBox[{"-", "1.5"}]}], "}"}]}], "}"}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ecc", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
            RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"ToString", "[", 
             RowBox[{"NumberForm", "[", 
              RowBox[{"e", ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.4"}], ",", "1.3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
        "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "=", 
      RowBox[{"1", "/", "ip"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pl1", ",", "pl2"}], "}"}], "=", 
      RowBox[{"NumeratorDenominator", "[", "p", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pt", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"pl1", " ", ">", " ", "pl2"}], ",", " ", "pl1", ",", " ", 
        "pl2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"reson", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ToString", "[", "pl2", "]"}], "<>", "\"\<:\>\"", "<>", 
            RowBox[{"ToString", "[", "pl1", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"1.2", ",", "1.3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"time", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"pt", "*", "2", "*", "Pi"}], ",", "dt"}], "}"}]}], "]"}]}], 
     ";", 
     RowBox[{"posvec", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "[", 
          RowBox[{"#", ",", "a", ",", "e"}], "]"}], "&"}], ",", "time"}], 
       "]"}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "posvec"}], "]"}]}], ";", " ", 
     RowBox[{"rad", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}], 
         "&"}], ",", "posvec"}], "]"}]}], ";", 
     RowBox[{"points", " ", "=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"p", "*", "time"}], "-", "f"}], "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"p", "*", "time"}], "-", "f"}], "]"}]}]}], "}"}], "]"}]}],
      ";", 
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"points", ",", 
        RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", 
        RowBox[{"Axes", "->", "None"}], ",", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"AbsolutePointSize", "[", "4", "]"}]}], ",", " ", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}]}], "]"}]}], 
     ";", 
     RowBox[{"Show", "[", 
      RowBox[{"box", ",", "ecc", ",", "reson", ",", "sun", ",", "p1", ",", 
       RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
       RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.878888212855723*^9, 3.878888422993389*^9}, 
   3.878890571863344*^9, {3.878896200053877*^9, 3.878896225913377*^9}, {
   3.878896463670061*^9, 3.878896502863688*^9}, {3.8789846929602413`*^9, 
   3.878984696664216*^9}, {3.878984729154007*^9, 3.8789847338634577`*^9}, {
   3.87898479578459*^9, 3.878984876934319*^9}, {3.87898504438087*^9, 
   3.8789850779199047`*^9}, {3.878985791487775*^9, 3.878985831864037*^9}, {
   3.878986139669623*^9, 3.878986194240117*^9}, {3.878986644122645*^9, 
   3.8789867952178373`*^9}, {3.878986942580975*^9, 3.8789869507239637`*^9}, {
   3.878987059895121*^9, 3.878987083684828*^9}, {3.878987132766487*^9, 
   3.878987172966803*^9}, {3.8789875448039417`*^9, 3.8789875688323507`*^9}, {
   3.878987969412224*^9, 3.878988067525758*^9}, 3.878988099462805*^9, {
   3.8789881397369747`*^9, 3.878988153670249*^9}, {3.8789882343119164`*^9, 
   3.8789882474810877`*^9}, {3.87898829509144*^9, 3.878988301525454*^9}, {
   3.878988877058762*^9, 3.878988878826676*^9}, {3.878989915972705*^9, 
   3.878989926396101*^9}, {3.87898996514467*^9, 3.878989989775057*^9}, {
   3.879066869180976*^9, 3.879066943354094*^9}, {3.8790674156400547`*^9, 
   3.879067416432426*^9}, {3.8790676028392363`*^9, 3.879067605387931*^9}, {
   3.879067830781068*^9, 3.879067869342317*^9}, {3.879067905222876*^9, 
   3.879067939977397*^9}, {3.879068505973906*^9, 3.879068528876381*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"cb412060-27c6-4319-be56-3418b3db549c"],

Cell[TextData[{
 "Now use the ",
 StyleBox["Manipulate", "Input"],
 " function to show how the path varies with eccentricity, ",
 StyleBox["e,",
  FontSlant->"Italic"],
 " for first order resonances",
 ". In this frame the planet is always located at (1,0).  Each plot covers \
the range -1.5 < x < 1.5 and -1.5 < y < 1.5.  Note that for each rational \
there is a critical value of the eccentricity where the asteroid is \
stationary in the rotating frame (i.e. it has an angular velocity that \
matches the planet); this leads to a cusp in the path in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878989305138673*^9, 3.87898933975825*^9}, {
  3.879068897649115*^9, 3.8790689334860697`*^9}, {3.87906914089135*^9, 
  3.879069263620009*^9}, {3.879069302754492*^9, 3.87906933759958*^9}, {
  3.879069582892926*^9, 3.8790696148122*^9}, {3.879069661735491*^9, 
  3.87906968157679*^9}, {3.87906973004116*^9, 3.8790697585266848`*^9}, {
  3.881040591042988*^9, 3.881040598301194*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5ca3c023-1a1a-4e8f-9aa9-3300654c692f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"PlotPath", "[", 
    RowBox[{"p", ",", "1", ",", "e", ",", 
     RowBox[{"Pi", "/", "20"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"e", ",", "0", ",", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}], ",", "0", 
     ",", "0.5", ",", "0.001"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "/", "1"}], ",", 
       RowBox[{"3", "/", "2"}], ",", 
       RowBox[{"4", "/", "3"}], ",", 
       RowBox[{"5", "/", "4"}], ",", 
       RowBox[{"6", "/", "5"}], ",", 
       RowBox[{"7", "/", "6"}], ",", 
       RowBox[{"8", "/", "7"}], ",", 
       RowBox[{"9", "/", "8"}], ",", 
       RowBox[{"10", "/", "9"}], ",", 
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"2", "/", "3"}], ",", 
       RowBox[{"3", "/", "4"}], ",", 
       RowBox[{"4", "/", "5"}], ",", 
       RowBox[{"5", "/", "6"}], ",", 
       RowBox[{"6", "/", "7"}], ",", 
       RowBox[{"7", "/", "8"}], ",", 
       RowBox[{"8", "/", "9"}], ",", 
       RowBox[{"9", "/", "10"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Resonance Path in Rotating Frame\>\"", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8788953805524406`*^9, 3.8788954549317207`*^9}, {
   3.878895513598167*^9, 3.8788955470764627`*^9}, {3.878895706315723*^9, 
   3.878895731094998*^9}, {3.878895840926024*^9, 3.878895938948222*^9}, {
   3.8788960123432198`*^9, 3.878896014848238*^9}, {3.878984896493156*^9, 
   3.878984898847805*^9}, {3.878984946084016*^9, 3.878984966167389*^9}, {
   3.878985004328421*^9, 3.8789850073286943`*^9}, {3.878985879801477*^9, 
   3.878985904024413*^9}, {3.878985952962614*^9, 3.878985974352064*^9}, {
   3.8789860928542137`*^9, 3.8789861053932056`*^9}, {3.878986208041655*^9, 
   3.878986316863799*^9}, {3.878987280696516*^9, 3.8789873099750834`*^9}, {
   3.8789873428709793`*^9, 3.878987484035095*^9}, 3.878988284799224*^9, {
   3.8789885873319902`*^9, 3.878988616672331*^9}, {3.8789886523152933`*^9, 
   3.878988673761491*^9}, {3.878988728230291*^9, 3.878988766762167*^9}, {
   3.878988823506239*^9, 3.8789888305554934`*^9}, {3.879067000637117*^9, 
   3.879067038931735*^9}, {3.879067075653125*^9, 3.87906708166786*^9}, {
   3.8790671394332857`*^9, 3.879067148432308*^9}, {3.879067193928823*^9, 
   3.8790672215168962`*^9}, {3.8790679504609203`*^9, 
   3.8790679516605453`*^9}, {3.879068411741334*^9, 3.879068412312365*^9}, 
   3.8790684752213993`*^9, {3.8790685624917603`*^9, 3.8790685972012587`*^9}, {
   3.879068655236416*^9, 3.879068667175209*^9}, {3.879068715687022*^9, 
   3.879068740135859*^9}, {3.879069382915621*^9, 3.879069385689728*^9}, 
   3.879069795427911*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"c5c2c0e5-b8a0-41aa-8df9-11e4f4292de5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`e$$ = 0, $CellContext`p$$ = Rational[1, 2], 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`e$$], 0, 
       Style[
       "\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, 0, 
      0.5, 0.001}, {{
       Hold[$CellContext`p$$], 
       Rational[1, 2], 
       Style[
       "\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, {2, 
       Rational[3, 2], 
       Rational[4, 3], 
       Rational[5, 4], 
       Rational[6, 5], 
       Rational[7, 6], 
       Rational[8, 7], 
       Rational[9, 8], 
       Rational[10, 9], 
       Rational[1, 2], 
       Rational[2, 3], 
       Rational[3, 4], 
       Rational[4, 5], 
       Rational[5, 6], 
       Rational[6, 7], 
       Rational[7, 8], 
       Rational[8, 9], 
       Rational[9, 10]}}}, Typeset`size$$ = {360., {177., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`e$$ = 0, $CellContext`p$$ = 
        Rational[1, 2]}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`PlotPath[$CellContext`p$$, 1, $CellContext`e$$, 
        Pi/20], "Specifications" :> {{{$CellContext`e$$, 0, 
          Style[
          "\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, 0, 
         0.5, 0.001}, {{$CellContext`p$$, 
          Rational[1, 2], 
          Style[
          "\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, {2, 
          Rational[3, 2], 
          Rational[4, 3], 
          Rational[5, 4], 
          Rational[6, 5], 
          Rational[7, 6], 
          Rational[8, 7], 
          Rational[9, 8], 
          Rational[10, 9], 
          Rational[1, 2], 
          Rational[2, 3], 
          Rational[3, 4], 
          Rational[4, 5], 
          Rational[5, 6], 
          Rational[6, 7], 
          Rational[7, 8], 
          Rational[8, 9], 
          Rational[9, 10]}, ControlType -> SetterBar}}, 
      "Options" :> {
       FrameLabel -> 
        Style["Resonance Path in Rotating Frame", FontFamily -> "Times", 
          FontSize -> 16]}, "DefaultOptions" :> {}],
     ImageSizeCache->{404., {251., 256.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8789849042658157`*^9, 3.87898496778371*^9, 3.878985055096105*^9, 
   3.878985135545006*^9, {3.8789851707046824`*^9, 3.878985182511582*^9}, {
   3.878985865255105*^9, 3.8789859174417067`*^9}, {3.87898595435153*^9, 
   3.878985976523328*^9}, 3.878986108772938*^9, {3.878986318707699*^9, 
   3.8789863393606567`*^9}, 3.878987089943571*^9, {3.8789871375370893`*^9, 
   3.878987176670784*^9}, 3.878987311162073*^9, 3.878987349785954*^9, 
   3.878987399229052*^9, {3.878987430126811*^9, 3.878987506368734*^9}, 
   3.878988073925228*^9, 3.8789881070412827`*^9, 3.878988158592526*^9, 
   3.8789882528414307`*^9, 3.878988285922515*^9, 3.878988618296604*^9, 
   3.878988674437154*^9, 3.8789887681921997`*^9, {3.878989094485222*^9, 
   3.878989101741308*^9}, 3.878989875802702*^9, 3.8789899316533546`*^9, {
   3.8789899726019773`*^9, 3.8789899935703917`*^9}, {3.879067184519679*^9, 
   3.879067222786517*^9}, 3.879067428845685*^9, 3.879067580324628*^9, 
   3.879067616855913*^9, 3.8790678856127977`*^9, 3.879067952371072*^9, 
   3.879068414337419*^9, 3.8790684785714703`*^9, 3.8790685984820538`*^9, {
   3.8790686563301353`*^9, 3.879068668492195*^9}, 3.87906874169188*^9, 
   3.879069018668009*^9, {3.879069371834128*^9, 3.879069386574506*^9}, 
   3.879070126905398*^9, 3.87907015838142*^9, 3.881040681009004*^9, 
   3.881040729442865*^9, 3.8810409084822817`*^9, 3.890981972099258*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"a5cecd2f-dc82-4ff8-95e9-ef4402c2092d"]
}, Open  ]],

Cell[TextData[{
 "Now use the ",
 StyleBox["Manipulate", "Input"],
 " function to show how the path varies with eccentricity, ",
 StyleBox["e",
  FontSlant->"Italic"],
 ",  for second order resonances",
 ". In this frame the planet is always located at (1,0).  Each plot covers \
the range -1.5 < x < 1.5 and -1.5 < y < 1.5.  Note that for each rational \
there is a critical value of the eccentricity where the asteroid is \
stationary in the rotating frame (i.e. it has an angular velocity that \
matches the planet); this leads to a cusp in the path in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878989305138673*^9, 3.87898933975825*^9}, {
  3.879068897649115*^9, 3.8790689334860697`*^9}, {3.87906914089135*^9, 
  3.879069263620009*^9}, {3.879069302754492*^9, 3.87906933759958*^9}, {
  3.879069582892926*^9, 3.8790696148122*^9}, {3.879069661735491*^9, 
  3.87906968157679*^9}, {3.87906973004116*^9, 3.8790697585266848`*^9}, {
  3.8810406218369427`*^9, 3.881040633177371*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"79f9d247-16b2-4397-ac15-e84ea449ae02"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"PlotPath", "[", 
    RowBox[{"p", ",", "1", ",", "e", ",", 
     RowBox[{"Pi", "/", "20"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"e", ",", "0", ",", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}], ",", "0", 
     ",", "0.5", ",", "0.001"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"3", "/", "1"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "/", "1"}], ",", 
       RowBox[{"5", "/", "3"}], ",", 
       RowBox[{"7", "/", "5"}], ",", 
       RowBox[{"9", "/", "7"}], ",", 
       RowBox[{"1", "/", "3"}], ",", 
       RowBox[{"3", "/", "5"}], ",", 
       RowBox[{"5", "/", "7"}], ",", 
       RowBox[{"7", "/", "9"}], ",", 
       RowBox[{"9", "/", "11"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Resonance Path in Rotating Frame\>\"", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8788953805524406`*^9, 3.8788954549317207`*^9}, {
   3.878895513598167*^9, 3.8788955470764627`*^9}, {3.878895706315723*^9, 
   3.878895731094998*^9}, {3.878895840926024*^9, 3.878895938948222*^9}, {
   3.8788960123432198`*^9, 3.878896014848238*^9}, {3.878984896493156*^9, 
   3.878984898847805*^9}, {3.878984946084016*^9, 3.878984966167389*^9}, {
   3.878985004328421*^9, 3.8789850073286943`*^9}, {3.878985879801477*^9, 
   3.878985904024413*^9}, {3.878985952962614*^9, 3.878985974352064*^9}, {
   3.8789860928542137`*^9, 3.8789861053932056`*^9}, {3.878986208041655*^9, 
   3.878986316863799*^9}, {3.878987280696516*^9, 3.8789873099750834`*^9}, {
   3.8789873428709793`*^9, 3.878987484035095*^9}, 3.878988284799224*^9, {
   3.8789885873319902`*^9, 3.878988616672331*^9}, {3.8789886523152933`*^9, 
   3.878988673761491*^9}, {3.878988728230291*^9, 3.878988766762167*^9}, {
   3.878988823506239*^9, 3.8789888305554934`*^9}, {3.879067000637117*^9, 
   3.879067038931735*^9}, {3.879067075653125*^9, 3.87906708166786*^9}, {
   3.8790671394332857`*^9, 3.879067148432308*^9}, {3.879067193928823*^9, 
   3.8790672215168962`*^9}, {3.8790679504609203`*^9, 
   3.8790679516605453`*^9}, {3.879068411741334*^9, 3.879068412312365*^9}, 
   3.8790684752213993`*^9, {3.8790685624917603`*^9, 3.8790685972012587`*^9}, {
   3.879068655236416*^9, 3.879068667175209*^9}, {3.879068715687022*^9, 
   3.879068740135859*^9}, {3.879069382915621*^9, 3.879069385689728*^9}, 
   3.879069795427911*^9, {3.8809567524393177`*^9, 3.880956816230947*^9}, {
   3.8810407204205923`*^9, 3.881040722711998*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"fb26790b-10cf-4b95-bbc3-5d46e86ea2c1"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`e$$ = 0, $CellContext`p$$ = 3, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`e$$], 0, 
       Style[
       "\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, 0, 
      0.5, 0.001}, {{
       Hold[$CellContext`p$$], 3, 
       Style[
       "\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, {3, 
       Rational[5, 3], 
       Rational[7, 5], 
       Rational[9, 7], 
       Rational[1, 3], 
       Rational[3, 5], 
       Rational[5, 7], 
       Rational[7, 9], 
       Rational[9, 11]}}}, Typeset`size$$ = {360., {177., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`e$$ = 0, $CellContext`p$$ = 3}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`PlotPath[$CellContext`p$$, 1, $CellContext`e$$, 
        Pi/20], "Specifications" :> {{{$CellContext`e$$, 0, 
          Style[
          "\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, 0, 
         0.5, 0.001}, {{$CellContext`p$$, 3, 
          Style[
          "\!\(\*StyleBox[\"p\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\):", FontFamily -> "Times", FontSize -> 16]}, {3, 
          Rational[5, 3], 
          Rational[7, 5], 
          Rational[9, 7], 
          Rational[1, 3], 
          Rational[3, 5], 
          Rational[5, 7], 
          Rational[7, 9], 
          Rational[9, 11]}, ControlType -> SetterBar}}, 
      "Options" :> {
       FrameLabel -> 
        Style["Resonance Path in Rotating Frame", FontFamily -> "Times", 
          FontSize -> 16]}, "DefaultOptions" :> {}],
     ImageSizeCache->{404., {251., 256.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.881040681298067*^9, {3.881040724524132*^9, 3.8810407295532303`*^9}, 
   3.881040908806572*^9, 3.890981972404256*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"420c789d-bcf4-4a42-b8eb-a59fb93d5b9a"]
},
CellGrouping->Manual,
WindowSize->{1053, 666},
WindowMargins->{{84, Automatic}, {Automatic, 27}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"96d35ddf-8ae6-41b2-8c2a-36a9f36af1c8"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"d70f6fec-3c94-4334-b140-c970390eeeae"],
Cell[1000, 31, 192, 3, 67, "Section",ExpressionUUID->"31388b24-5a67-47bb-905c-6837e1749e38"],
Cell[1195, 36, 172, 3, 49, "Text",ExpressionUUID->"6b6891c1-2af0-4bfa-b36f-abfe3bef8e91"],
Cell[1370, 41, 441, 12, 30, "Input",ExpressionUUID->"e248a262-4101-4663-b917-10e388c56dd2"],
Cell[1814, 55, 387, 9, 53, "Text",ExpressionUUID->"7bfcd704-b949-42b8-8539-4c61eb807e08"],
Cell[2204, 66, 551, 14, 30, "Input",ExpressionUUID->"a8483631-6fc6-4f4c-be66-5810b4a15242"],
Cell[2758, 82, 369, 13, 53, "Text",ExpressionUUID->"e13b727c-2449-4d76-92b2-53e884252fd8"],
Cell[3130, 97, 945, 27, 94, "Input",ExpressionUUID->"c35cf962-88a8-4778-ae92-4c686bb2d8ec"],
Cell[4078, 126, 587, 15, 76, "Text",ExpressionUUID->"0f46952f-34a4-4164-9f9d-bcc764542c65"],
Cell[4668, 143, 7613, 188, 451, "Input",ExpressionUUID->"cb412060-27c6-4319-be56-3418b3db549c"],
Cell[12284, 333, 1096, 21, 122, "Text",ExpressionUUID->"5ca3c023-1a1a-4e8f-9aa9-3300654c692f"],
Cell[CellGroupData[{
Cell[13405, 358, 3680, 75, 115, "Input",ExpressionUUID->"c5c2c0e5-b8a0-41aa-8df9-11e4f4292de5"],
Cell[17088, 435, 4863, 107, 526, "Output",ExpressionUUID->"a5cecd2f-dc82-4ff8-95e9-ef4402c2092d"]
}, Open  ]],
Cell[21966, 545, 1100, 21, 122, "Text",ExpressionUUID->"79f9d247-16b2-4397-ac15-e84ea449ae02"],
Cell[23069, 568, 3437, 67, 94, "Input",ExpressionUUID->"fb26790b-10cf-4b95-bbc3-5d46e86ea2c1"],
Cell[26509, 637, 3071, 70, 526, "Output",ExpressionUUID->"420c789d-bcf4-4a42-b8eb-a59fb93d5b9a"]
}
]
*)

